@@ -27,4 +27,7 @@ except ModuleNotFoundError:
   pass
 
 
-__version__ = "1.2.1"
+__version__ = "1.2.2"
+
+if __name__ == "__main__":
+  print("{}\n\nVersion: {}".format(__doc__, __version__))
